{% extends 'auth/base.html' %} 

{% block content %}
<div class="row">
    <div class="col-xs-8 col-xs-offset-2">
        <div class="panel panel-default">
            <div class="panel-heading">Dashboard</div>
            <div class="panel-body">
                This is a dashboard. Hello {{ Auth.user().name }}
            </div>
        </div>
    </div>
</div>
{% endblock %}