from setuptools import setup

setup(
    name='masonite',
    packages=[
        'masonite',
        'masonite.auth',
        'masonite.facades',
        'masonite.providers',
        'masonite.commands',
        'masonite.drivers',
        'masonite.managers',
        'masonite.testsuite',
        'masonite.queues',
        'masonite.contracts',
        'masonite.helpers',
    ],
    version='1.6.6',
    install_requires=[
        'validator.py==1.2.5',
        'cryptography==2.2.2',
        'bcrypt==3.1.4',
        'requests==2.18.4',
        'tldextract==2.2.0',
        'Jinja2==2.10',
        'python-dotenv==0.7.1',
        'passlib==1.7.1',
        'whitenoise==3.3.1',
        'bcrypt==3.1.4',
        'pytest==3.3.1',
        'orator==0.9.7',
        'cryptography==2.1.4',
        'PyMySQL==0.8.0',
        'psycopg2==2.7.3.2',
        'masonite-entry>=0.0.0,<=0.9.99',
        'pendulum==1.4.4',
        'cleo==0.6.5',
    ],
    description='The core for the Masonite framework',
    author='Joseph Mancuso',
    author_email='idmann509@gmail.com',
    url='https://github.com/MasoniteFramework/masonite',
    keywords=['python web framework', 'python3'],
    classifiers=[],
    include_package_data=True,
)
