{% extends 'auth/base.html' %}

{% block content %}
    <div class="row">
        <div class="col-xs-4 col-xs-offset-4">
            <div class="panel panel-default">
                <div class="panel-heading">Login</div>
                <div class="panel-body">
                <form action="/login" method="POST">
                    {{ csrf_field|safe }}

                    <div class="form-group">
                        <label for="">Username</label>
                        <input type="text" name="username" class="form-control">    
                    </div>

                    <div class="form-group">
                        <label for="">Password</label>
                        <input type="password" name="password" class="form-control">    
                    </div>
                    
                    <div class="form-group text-center">
                        <button type="submit" class="btn btn-success">Login</button>
                    </div>
                </form>
                </div>
            </div>    
        </div>
    </div>
{% endblock %}
